@@ -346,7 +346,8 @@ class EquivariantAttention(nn.Module):
 
         if self.rel_pos_emb:
             seq = torch.arange(n, device = device, dtype = q.dtype)
-            seq_rel_dist = rearrange(seq, 'i -> 1 i 1') - nbhd_indices
+            seq_target_pos = nbhd_indices if exists(nbhd_indices) else rearrange(seq, 'j -> 1 1 j')
+            seq_rel_dist = rearrange(seq, 'i -> 1 i 1') - seq_target_pos
             seq_rel_dist = repeat(seq_rel_dist, 'b i j -> b 1 i j 1', b = b)
             rel_dist = torch.cat((rel_dist, seq_rel_dist), dim = -1)
 
